sgfirebasetools

package
v0.363.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Command

func Command(ctx context.Context, args ...string) *exec.Cmd

func DeployPreview

func DeployPreview(ctx context.Context, opts DeployPreviewOptions) (string, error)

DeployPreview deploy static files to a Firebase hosting channel. Returns the generated URL for the hosting channel.

func PrepareCommand

func PrepareCommand(ctx context.Context) error

Types

type DeployPreviewOptions

type DeployPreviewOptions struct {
	// Project to deploy in.
	Project string
	// Site can be set if the firebase config contains config for multiple sites. Channel will be deployed to this site.
	Site string
	// ChannelID of the preview channel. If it does not exist, it will be created.
	ChannelID string
	// CmdDir can be set if the firebase.json file is not in root of repository.
	CmdDir string
	// Expires sets the duration until channel expires.
	// Defaults to 7 days.
	// Examples: "12h", "7d", "30d"
	Expires string
}

Jump to