sgpostgres

package
v0.334.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 11, 2024 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunLocal

func RunLocal(
	ctx context.Context,
	databaseName string,
	databasePassword string,
) (_ func(), err error)

RunLocal runs a postgres instance in Docker on the local host.

Primary goal is to have a shared local instance for test runs. Heavily inspired by Spanner emulator, tools/sgcloudspanner/emulator.go .

Types

This section is empty.

Jump to