Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeployPreview ¶
func DeployPreview(ctx context.Context, opts DeployPreviewOptions) (string, error)
DeployPreview deploy static files to a Firebase hosting channel. Returns the generated URL for the hosting channel.
func PrepareCommand ¶
Types ¶
type DeployPreviewOptions ¶
type DeployPreviewOptions struct {
// Project to deploy in.
Project string
// Site can be set if the firebase config contains config for multiple sites. Channel will be deployed to this site.
Site string
// ChannelID of the preview channel. If it does not exist, it will be created.
ChannelID string
// CmdDir can be set if the firebase.json file is not in root of repository.
CmdDir string
// Expires sets the duration until channel expires.
// Defaults to 7 days.
// Examples: "12h", "7d", "30d"
Expires string
}
Click to show internal directories.
Click to hide internal directories.