Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunLocal ¶
func RunLocal( ctx context.Context, databaseName string, databasePassword string, ) (_ func(), err error)
RunLocal runs a postgres instance in Docker on the local host.
Primary goal is to have a shared local instance for test runs. Heavily inspired by Spanner emulator, tools/sgcloudspanner/emulator.go .
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.